package com.huatek.frame.base.service;

import java.util.Map;

import com.huatek.frame.base.dto.PermissionDTO;
import com.huatek.frame.base.entity.Permission;

/**
 * 系统_资源 Service
 *
 * @author key_dong
 * @date 2018-7-11 14:03:46
 */
public interface PermissionService {

    /**
     * 分页查找查找 系统_资源
     *
     * @param page 页码
     * @param limit 每页显示数量
     * @param dto 系统_资源dto
     * @return map map
     */
    Map<String, Object> findPermissionPage(PermissionDTO dto);


    /**
     * 添加 系统_资源
     * 
     * @param permission 系统_资源permission
     * @return map map
     */
    Map<String, Object> addPermission(Permission permission);

    /**
     *  通过id查找 系统_资源
     *
     * @param id 主键
     * @return map map
     */
    Map<String, Object> findPermission(String id);

    /**
     * 修改 系统_资源
     * 
     * @param permission 系统_资源permission
     * @return map map
     */
    Map<String, Object> updatePermission( Permission permission);

    /**
      * 删除 系统_资源
      * 
      * @param ids 主键集合
      * @return map map
      */
    Map<String, Object> deletePermission( String[] ids);

    /**
     *  菜单集合
     * @param id
     * @return
     */
	Map<String, Object> findPermissions(String id); 
}
